#
# Author: Bas van der Vlies
# Date  : 19 Aug 2009
# Desc. : Common functions for the daemon and client program

import os
import subprocess
try:
    import configparser
except ImportError:
    import ConfigParser as configparser

class PxeConfig(Exception):
       def __init__(self, msg=''):
               self.msg = msg
               Exception.__init__(self, msg)

       def __repr__(self):
               return self.msg

def ReadConfig():
    """
    Parse the config file
    """
    file = '/etc/pxeconfig.conf'

    if not os.path.isfile(file):
        error = 'File %s does not exist' %file
        raise PxeConfig(error)

    config = configparser.RawConfigParser()
    try:
        config.read(file)
    except configparser.MissingSectionHeaderError as detail:
        raise PxeConfig(detail)

    # Not yet uses
    #
    #projects = {}
    #for section in config.sections():
    #	projects[section] = {}
    #	for option in  config.options(section):
    #	projects[section][option] = config.get(section, option)

    stanza = config.defaults()
    return config, stanza


def run_command(opts, command):

    if not opts:
            VERBOSE = False
    else:
        VERBOSE = opts.VERBOSE

    proc = subprocess.Popen(command, shell=True, stderr=subprocess.PIPE, stdout=subprocess.PIPE)
    stdout, stderr = proc.communicate()

    if proc.returncode != 0:
        if VERBOSE:
            print('Hook {} script returned an error'.format(command))
            print(stderr.decode())
            print(stdout.decode())
        else:
            print('Failed to run hook command {}'.format(command))
    elif VERBOSE:
        print('\nOutput of {}'.format(command))
        print(stdout.decode())
        print()
